==> org.eclipse.objectteams.otdt.source_2.8.1.202006091155.jar: otdtcoreextsrc/org/eclipse/objectteams/otdt/internal/core/ext/OTCoreExtMessages.java <==
/**********************************************************************
 * This file is part of "Object Teams Development Tooling"-Software
 * 
 * Copyright 2003, 2014 Fraunhofer Gesellschaft, Munich, Germany,
 * for its Fraunhofer Institute for Computer Architecture and Software
 * Technology (FIRST), Berlin, Germany and Technical University Berlin,
 * Germany.
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Please visit http://www.eclipse.org/objectteams for updates and contact.
 * 
 * Contributors:
 * Fraunhofer FIRST - Initial API and implementation
 * Technical University Berlin - Initial API and implementation
 **********************************************************************/
package org.eclipse.objectteams.otdt.internal.core.ext;

import org.eclipse.osgi.util.NLS;

public class OTCoreExtMessages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.objectteams.otdt.internal.core.ext.OTCoreExtMessages"; //$NON-NLS-1$

	public static String OTREContainer__Description;

	public static String OTREContainer_otre_not_found;

	public static String AbstractMarkable_baseClassHierarchy_progress;

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, OTCoreExtMessages.class);
	}

	private OTCoreExtMessages() {
		// don't instantiate
	}
}

==> org.eclipse.objectteams.otdt.source_2.8.3.202503130009.jar: otdtcoreextsrc/org/eclipse/objectteams/otdt/internal/core/ext/OTCoreExtMessages.java <==
/**********************************************************************
 * This file is part of "Object Teams Development Tooling"-Software
 * 
 * Copyright 2003, 2014 Fraunhofer Gesellschaft, Munich, Germany,
 * for its Fraunhofer Institute for Computer Architecture and Software
 * Technology (FIRST), Berlin, Germany and Technical University Berlin,
 * Germany.
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Please visit http://www.eclipse.org/objectteams for updates and contact.
 * 
 * Contributors:
 * Fraunhofer FIRST - Initial API and implementation
 * Technical University Berlin - Initial API and implementation
 **********************************************************************/
package org.eclipse.objectteams.otdt.internal.core.ext;

import org.eclipse.osgi.util.NLS;

public class OTCoreExtMessages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.objectteams.otdt.internal.core.ext.OTCoreExtMessages"; //$NON-NLS-1$

	public static String OTREContainer__Description;

	public static String OTREContainer_otre_not_found;

	public static String OTTypeHierarchies_noJavaElement_error;

	public static String OTVariableInitializer_initialization_error;

	public static String OTVariableInitializer_OTDT_installation_path_error;

	public static String OTVariableInitializer_path_from_bundle_error;

	public static String OTVariableInitializer_uninstalled_bundle_info;

	public static String AbstractMarkable_baseClassHierarchy_progress;

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, OTCoreExtMessages.class);
	}

	private OTCoreExtMessages() {
		// don't instantiate
	}
}
